aboutsummaryrefslogtreecommitdiffstats
path: root/wsutil/filesystem.h
diff options
context:
space:
mode:
authorJoão Valverde <j@v6e.pt>2019-10-10 15:34:46 +0000
committerJoão Valverde <j@v6e.pt>2019-10-10 15:58:41 +0000
commit97cb389a3531269b3c86555156a2bba62ccfd8a5 (patch)
tree16a7b35a0e1a1411fcf11ff3e05af31b2e2c57ae /wsutil/filesystem.h
parent51fbc7198ef3ebd49c3c491e4a5b3ed72eec278d (diff)
Revert "CMake: Don't install HTML manuals twice"
This reverts commit f1285fcf061669702ca1accd7b2c50ebc8198993. NSIS package is broken with this commit. Change-Id: Ief22a308edad188fa2d5fab79355f19493359fa6 Reviewed-on: https://code.wireshark.org/review/34758 Petri-Dish: João Valverde <j@v6e.pt> Tested-by: Petri Dish Buildbot Reviewed-by: João Valverde <j@v6e.pt>
Diffstat (limited to 'wsutil/filesystem.h')
-rw-r--r--wsutil/filesystem.h13
1 files changed, 4 insertions, 9 deletions
diff --git a/wsutil/filesystem.h b/wsutil/filesystem.h
index e34a3616e6..b204fe5932 100644
--- a/wsutil/filesystem.h
+++ b/wsutil/filesystem.h
@@ -66,11 +66,6 @@ WS_DLL_PUBLIC const char *get_plugins_pers_dir_with_version(void);
WS_DLL_PUBLIC const char *get_extcap_dir(void);
/*
- * Get the directory in which document files are stored.
- */
-WS_DLL_PUBLIC const char *get_docfile_dir(void);
-
-/*
* Get the flag indicating whether we're running from a build
* directory.
*/
@@ -326,15 +321,15 @@ WS_DLL_PUBLIC gboolean copy_file_binary_mode(const char *from_filename,
/*
- * Given a help filename return a filesystem URL. Relative paths are prefixed with
- * the directory path.
+ * Given a filename return a filesystem URL. Relative paths are prefixed with
+ * the datafile directory path.
*
* @param filename A file name or path. Relative paths will be prefixed with
* the directory path.
* @return A filesystem URL for the file or NULL on failure. A non-NULL return
* value must be freed with g_free().
*/
-WS_DLL_PUBLIC gchar* help_file_url(const gchar *filename);
+WS_DLL_PUBLIC gchar* data_file_url(const gchar *filename);
/*
* Free the internal structtures
@@ -326,15 +321,15 @@ WS_DLL_PUBLIC gboolean copy_file_binary_mode(const char *from_filename,
*
* @param filename A file name or path. Relative paths will be prefixed with
- * the directory path.
+ * the data file directory path.
* @return A filesystem URL for the file or NULL on failure. A non-NULL return
* value must be freed with g_free().